@@ -109,7 +109,7 @@ typedef struct _EvHeightToPageCache {
 } EvHeightToPageCache;
 
 struct _EvView {
-	GtkLayout layout;
+	GtkContainer layout;
 
 	/* Container */
 	GList *children;
@@ -160,11 +160,13 @@ struct _EvView {
 	gint spacing;
 
 	gboolean loading;
+	gboolean can_zoom_in;
+	gboolean can_zoom_out;
 	gboolean continuous;
-	gboolean dual_page;
 	gboolean dual_even_left;
 	gboolean fullscreen;
 	EvSizingMode sizing_mode;
+	EvPageLayout page_layout;
 	GtkWidget *loading_window;
 	guint loading_timeout;
 
@@ -202,11 +204,11 @@ struct _EvView {
 	EvMapping *synctex_result;
 
 	/* Accessibility */
-	gboolean a11y_enabled;
+	AtkObject *accessible;
 };
 
 struct _EvViewClass {
-	GtkLayoutClass parent_class;
+	GtkContainerClass parent_class;
 
 	void    (*binding_activated)	  (EvView         *view,
 					   GtkScrollType   scroll,
